@@ -54,8 +54,8 @@ function(xdat, threshold, npy = 365, ydat = NULL, sigl = NULL, shl = NULL, sigli
 	xdatu <- xdat[xdat > u]
 	xind <- (1:n)[xdat > u]
 	u <- u[xind]
-	in2 <- sqrt(6 * var(xdat))/pi
-	in1 <- mean(xdat, na.rm = TRUE) - 0.57722 * in2
+	in2 <- sqrt(6 * var(xdatu))/pi
+	in1 <- mean(xdatu, na.rm = TRUE) - 0.57722 * in2
 	if(is.null(sigl)) {
 		sigmat <- as.matrix(rep(1, length(xdatu)))
 		if( is.null( siginit)) siginit <- in2
